summaryrefslogtreecommitdiffstats
path: root/IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c
diff options
context:
space:
mode:
Diffstat (limited to 'IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c')
-rw-r--r--IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c b/IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c
index 241cd284fb..97cae9ad9d 100644
--- a/IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c
+++ b/IntelFspPkg/Library/BaseFspPlatformLib/FspPlatformMemory.c
@@ -68,7 +68,7 @@ FspGetSystemMemorySize (
}
/**
- Migrate bootloader data before destroying CAR.
+ Migrate BootLoader data before destroying CAR.
**/
VOID
@@ -93,7 +93,7 @@ FspMigrateTemporaryMemory (
ApiMode = GetFspApiCallingMode ();
//
// Get the temporary memory range used by the bootloader
//
BootLoaderTempRamStart = PcdGet32(PcdTemporaryRamBase);
BootLoaderTempRamSize = PcdGet32(PcdTemporaryRamSize) - PcdGet32(PcdFspTemporaryRamSize);
@@ -93,7 +93,7 @@ FspMigrateTemporaryMemory (
ApiMode = GetFspApiCallingMode ();
//
- // Get the temporary memory range used by the bootloader
+ // Get the temporary memory range used by the BootLoader
//
BootLoaderTempRamStart = PcdGet32(PcdTemporaryRamBase);